[open-ils-commits] r15037 - trunk/Open-ILS/web/js/dojo/MARC (miker)

svn at svn.open-ils.org svn at svn.open-ils.org
Sat Nov 28 18:32:38 EST 2009


Author: miker
Date: 2009-11-28 18:32:32 -0500 (Sat, 28 Nov 2009)
New Revision: 15037

Modified:
   trunk/Open-ILS/web/js/dojo/MARC/Batch.js
Log:
use the correct name for marcbreaker format; add support for sf delimiter to batches

Modified: trunk/Open-ILS/web/js/dojo/MARC/Batch.js
===================================================================
--- trunk/Open-ILS/web/js/dojo/MARC/Batch.js	2009-11-28 23:15:21 UTC (rev 15036)
+++ trunk/Open-ILS/web/js/dojo/MARC/Batch.js	2009-11-28 23:32:32 UTC (rev 15037)
@@ -27,6 +27,7 @@
             this.ready = false;
             this.records = [];
             this.source = kwargs.source;
+            this.delimiter = kwargs.delimiter
             this.current_record = 0;
 
             if (this.source) this.ready = true;
@@ -42,9 +43,9 @@
             } else if (this.source.match(/^\s*</)) { // this is xml text
                 this.source = dojox.xml.parser.parse( this.source );
                 this.parse();
-            } else { // must be a breaker doc. split on blank lines
+            } else { // must be a marcbreaker doc. split on blank lines
                 this.source = this.source.split(/^$/);
-                this.type = 'breaker';
+                this.type = 'marcbreaker';
             }
         },
 
@@ -67,6 +68,7 @@
             if (chunk) {
                 var args = {};
                 args[this.type] = chunk;
+                if (this.delimiter) args.delimiter = this.delimiter;
                 return new MARC.Record(args);
             }
 



More information about the open-ils-commits mailing list